==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24TabSelectionHandler.h <==
// public class javax.swing.plaf.basic.BasicTabbedPaneUI$TabSelectionHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class af567d46bfac9fec javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24TabSelectionHandler.h <==
// public class javax.swing.plaf.basic.BasicTabbedPaneUI$TabSelectionHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class af567d46bfac9fec javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24TabSelectionHandler_H_ */
